hit-online-control
------------------

Description
~~~~~~~~~~~

Contains a wrapper for the ``BeamOptikDLL.dll`` control library of the HIT
accelerator facility for use with madgui_.

.. _madgui: https://github.com/coldfix/madgui

Dependencies
~~~~~~~~~~~~

The ``BeamOptikDLL.dll`` library needs to be accessible (PATH or CWD).

Setup
~~~~~

The setup is to be performed as follows

.. code-block:: bash

    python setup.py install

